"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pluralize = require("pluralize");
const change_case = require("change-case");
class InterfaceBuilder {
    constructor(settings, mysqlTypes) {
        this.settings = settings;
        this.mysqlTypes = mysqlTypes;
    }
    buildTypeRow(col) {
        let tabs = "\t";
        let optional = this.settings.optionalParameters ? "?" : "";
        let tsType = this.getTsType(col.type);
        let field = col.field;
        return `${tabs}"${field}"${optional}: ${tsType};\n`;
    }
    renderTs(tableName, table) {
        let className = this.getClassName(tableName);
        var stringBuilder = this.settings.defaultClassName + " " + className + " { \n";
        for (var colName in table) {
            stringBuilder += this.buildTypeRow(table[colName]);
        }
        stringBuilder += "}";
        let meta = `/**\n* Autogenerated interface, DO NOT MODIFY\n*/\n`;
        return meta + stringBuilder;
    }
    getTsType(type) {
        var ts = this.mysqlTypes[type];
        if (!ts) {
            console.error("Unknown type " + type);
            ts = "any";
        }
        return ts;
    }
    getClassName(tableName) {
        let name = this.settings.singularizeClassNames ? pluralize.singular(tableName) : tableName;
        return change_case.pascalCase(name);
    }
}
exports.default = InterfaceBuilder;
//# sourceMappingURL=interface-builder.js.map