"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars = require("handlebars");
const change_case = require("change-case");
const template = `/**
 * Auto generated, do not modify!
 */
export default class Columns {
    {{#each tables}}{{{this}}}{{/each}}
}
`;
const tableTemplate = `
  static readonly {{tableName}} = {
    {{{columns}}}
  }
`;
class TableColumnsBuilder {
    constructor(schema) {
        this.schema = schema;
        this.compiledTemplate = handlebars.compile(template);
        this.compiledTableTemplate = handlebars.compile(tableTemplate);
    }
    renderTemplate() {
        let tables = [];
        tables.push(...this.renderTableTemplates(this.schema.tables));
        tables.push(...this.renderTableTemplates(this.schema.views));
        let output = this.compiledTemplate({ tables: tables });
        return output;
    }
    renderColumns(table) {
        let arr = [];
        for (let key in table) {
            let field = table[key].field;
            let constCase = change_case.constantCase(field);
            arr.push(`${constCase}: '${field}'`);
        }
        return arr;
    }
    renderTableTamplate(tableName, table) {
        let columnsArr = this.renderColumns(table);
        let columns = columnsArr.join(", \n\t\t");
        tableName = change_case.constantCase(tableName);
        return this.compiledTableTemplate({ tableName: tableName, columns: columns });
    }
    renderTableTemplates(tables) {
        let templates = [];
        for (let key in tables) {
            templates.push(this.renderTableTamplate(key, tables[key]));
        }
        return templates;
    }
}
exports.default = TableColumnsBuilder;
//# sourceMappingURL=table-columns-builder.js.map